==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_up = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.vc = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.u3 = function () {
        _super.prototype.u3.call(this);
        this.va = this.vb;
        this.uo.c = this.va;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_yy = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.zl = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.zc = function () {
        _super.prototype.zc.call(this);
        this.zj = this.zk;
        this.yx.c = this.zj;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };
